==> edpm-1.0.28.tar.gz: edpm-1.0.28/edpm/recipes/algorithms.py <==
"""
Algorithms library:
https://github.com/eic/algorithms
"""

import os

from edpm.engine.commands import workdir, run
from edpm.engine.env_gen import Set, Append, Prepend
from edpm.engine.git_cmake_recipe import GitCmakeRecipe


class AlgorithmsRecipe(GitCmakeRecipe):
    """Provides data for building and installing Genfit framework
    source_path  = {app_path}/src/{version}          # Where the sources for the current version are located
    build_path   = {app_path}/build/{version}        # Where sources are built. Kind of temporary dir
    install_path = {app_path}/root-{version}         # Where the binary installation is
    """

    def __init__(self):
        """
        Installs Genfit track fitting framework
        """

        # Set initial values for parent class and self
        super(AlgorithmsRecipe, self).__init__('algorithms')                        # This name will be used in edpm commands
        self.config['branch'] = 'algorithms-integration'                               # The branch or tag to be cloned (-b flag)
        self.config['repo_address'] = 'https://github.com/eic/algorithms'    # Repo address
        self.config['cmake_flags'] = ' '
        self.config['cxx_standard'] = 17

    def setup(self, db):
        # Call GitCmakeRecipe `default` setup function
        super(AlgorithmsRecipe, self).setup(db)

        # cmake command:
        # the  -Wno-dev  flag is to ignore the project developers cmake warnings for policy CMP0075
        self.build_cmd = "cmake -Wno-dev " \
                         "-DCMAKE_INSTALL_PREFIX={install_path} -DCMAKE_CXX_STANDARD={cxx_standard} " \
                         "{cmake_flags} {cmake_custom_flags} {source_path}/external/algorithms" \
                         "&& cmake --build . -- -j {build_threads}" \
                         "&& cmake --build . --target install" \
                         .format(**self.config)

    @staticmethod
    def gen_env(data):
        """Generates environments to be set"""
        path = data['install_path']

        yield Set('ACTS_DIR', path)

        # it could be lib or lib64. There are bugs on different platforms (RHEL&centos and WSL included)
        # https://stackoverflow.com/questions/46847939/config-site-for-vendor-libs-on-centos-x86-64
        # https: // bugzilla.redhat.com / show_bug.cgi?id = 1510073

        import platform
        if platform.system() == 'Darwin':
            yield Append('DYLD_LIBRARY_PATH', os.path.join(path, 'lib'))

        yield Append('LD_LIBRARY_PATH', os.path.join(path, 'lib'))

        # share/cmake/Acts
        yield Append('CMAKE_PREFIX_PATH', os.path.join(path, 'lib', 'cmake', 'Acts'))
        yield Append('CMAKE_PREFIX_PATH', os.path.join(path, 'lib', 'cmake', 'nlohmann_json'))
        yield Append('CMAKE_PREFIX_PATH', os.path.join(path, 'lib', 'cmake', 'ActsDD4hep'))


    #
    # OS dependencies are a map of software packets installed by os maintainers
    # The map should be in form:
    # os_dependencies = { 'required': {'ubuntu': "space separated packet names", 'centos': "..."},
    #                     'optional': {'ubuntu': "space separated packet names", 'centos': "..."}
    # The idea behind is to generate easy to use instructions: 'sudo apt-get install ... ... ... '
    os_dependencies = {
        'required': {
            'ubuntu18': "libboost-dev libboost-filesystem-dev libboost-program-options-dev libboost-test-dev",
            'ubuntu22': "libboost-dev libboost-filesystem-dev libboost-program-options-dev libboost-test-dev",
            'centos7': "boost-devel",
            'centos8': "boost-devel",
        },
    }

==> edpm-1.0.43.tar.gz: edpm-1.0.43/edpm/recipes/algorithms.py <==
"""
Algorithms library:
https://github.com/eic/algorithms

"""

import os

import platform
from edpm.engine.env_gen import Set, Append, Prepend
from edpm.engine.git_cmake_recipe import GitCmakeRecipe


class AlgorithmsRecipe(GitCmakeRecipe):

    def __init__(self):

        # Set initial values for parent class and self
        super(AlgorithmsRecipe, self).__init__('algorithms')                 # This name will be used in edpm commands
        self.config['branch'] = 'algorithms-integration'                     # The branch or tag to be cloned (-b flag)
        self.config['repo_address'] = 'https://github.com/eic/algorithms'    # Repo address
        self.config['cmake_flags'] = ' '
        self.config['cxx_standard'] = 17

    def setup(self, db):
        # Call GitCmakeRecipe `default` setup function
        super(AlgorithmsRecipe, self).setup(db)

        # cmake command:
        # the  -Wno-dev  flag is to ignore the project developers cmake warnings for policy CMP0075
        self.build_cmd = "cmake -Wno-dev " \
                         "-DCMAKE_INSTALL_PREFIX={install_path} -DCMAKE_CXX_STANDARD={cxx_standard} " \
                         "{cmake_flags} {cmake_custom_flags} {source_path}/external/algorithms" \
                         "&& cmake --build . -- -j {build_threads}" \
                         "&& cmake --build . --target install" \
                         .format(**self.config)

    @staticmethod
    def gen_env(data):
        """Generates environments to be set"""
        install_path = data['install_path']

        if platform.system() == 'Darwin':
            yield Append('DYLD_LIBRARY_PATH', os.path.join(install_path, 'lib'))

        yield Append('LD_LIBRARY_PATH', os.path.join(install_path, 'lib'))


    #
    # OS dependencies are a map of software packets installed by os maintainers
    # The map should be in form:
    # os_dependencies = { 'required': {'ubuntu': "space separated packet names", 'centos': "..."},
    #                     'optional': {'ubuntu': "space separated packet names", 'centos': "..."}
    # The idea behind is to generate easy to use instructions: 'sudo apt-get install ... ... ... '
    os_dependencies = {
        'required': {
            'ubuntu18': "libmsgsl-dev",
            'ubuntu22': "libmsgsl-dev",
            'centos7': "guidelines-support-library",
            'centos8': "guidelines-support-library",
        },
    }
